# How it works
Yaghm operates based on a config file, which is treated as a wishlist of what hooks *should* be enabled in the target repo. These are composed into a list of commands (eg. `.git/hooks/pre-commit.yaghm.commands`). The actual hook entrypoint (eg. `.git/hooks/pre-commit`) is a Python script that invokes each command in the list. This script will be triggered by git as per the normal hooks behavior.
